@@ -43,7 +43,7 @@ def main():
   job_name, _, node_name = node_name.rpartition('-')
   CACHE_DIR = os.path.join(CONFIG_DIR, job_name)
   task_id = int(lp_task_id)
-  os.system(f'bash {CODE_DIR}/setup.sh')
+  # os.system(f'bash {CODE_DIR}/setup.sh')
   if os.path.exists(SOURCE_DIR):
     for dirpath in os.listdir(SOURCE_DIR):
       path = os.path.join(SOURCE_DIR, dirpath)
